pub enum DescriptionNameWidth {
Never,
Fixed(usize),
Auto,
}Expand description
DescriptionNameWidth enum defines how the width of item names is determined.
This enum is used when displaying item descriptions (DescriptionShowMode::CurrentOnly, and DescriptionShowMode::All).
Variants
Never
no width adjustment is made.
Fixed(usize)
fixed width adjustment is applied.
Auto
auto width adjustment based on the maximum name length.